Changelog
=========

Versions follow `CalVer <https://calver.org>`_  (0Y.Minor.Micro format).

Changes for the upcoming release can be found in the `"changelog.d" directory <https://github.com/jmaces/keras-adf/tree/master/changelog.d>`_ in our repository.

..
   Do *NOT* add changelog entries here!

   This changelog is managed by towncrier and is compiled at release time.

   See our contribution guide for details.

.. towncrier release notes start

19.1.0 (2019-12-27)
-------------------

Changes
^^^^^^^

- Initial release. `#1 <https://github.com/jmaces/keras-adf/issues/1>`_

  + kerasadf.activations.linear
  + kerasadf.activations.relu

  + kerasadf.layers.core.Dense
  + kerasadf.layers.core.Flatten

  + kerasadf.layers.convolutional.Conv1D
  + kerasadf.layers.convolutional.Conv2D

  + kerasadf.layers.pooling.AveragePooling1D
  + kerasadf.layers.pooling.AveragePooling2D


----
